@@ -1,19 +1,20 @@
 from __future__ import annotations
 
+import json
+import logging
 import os
 import re
-import json
-from typing import Generator, List, Literal, Optional, TypedDict, Union, TYPE_CHECKING
+from typing import TYPE_CHECKING, Iterator, Literal, TypedDict, cast
 
-from ._errors import FFmpegNormalizeError
 from ._cmd_utils import NUL, CommandRunner, dict_to_filter_opts
-from ._logger import setup_custom_logger
+from ._errors import FFmpegNormalizeError
 
 if TYPE_CHECKING:
     from ._ffmpeg_normalize import FFmpegNormalize
     from ._media_file import MediaFile
 
-logger = setup_custom_logger("ffmpeg_normalize")
+_logger = logging.getLogger(__name__)
+
 
 class EbuLoudnessStatistics(TypedDict):
     input_i: float
@@ -26,18 +27,27 @@ class EbuLoudnessStatistics(TypedDict):
     output_thresh: float
     target_offset: float
 
+
 class LoudnessStatistics(TypedDict):
-    ebu: Optional[EbuLoudnessStatistics]
-    mean: Optional[float]
-    max: Optional[float]
+    ebu: EbuLoudnessStatistics | None
+    mean: float | None
+    max: float | None
+
 
 class LoudnessStatisticsWithMetadata(LoudnessStatistics):
     input_file: str
     output_file: str
     stream_id: int
 
+
 class MediaStream:
-    def __init__(self, ffmpeg_normalize: FFmpegNormalize, media_file: MediaFile, stream_type: Literal["audio", "video", "subtitle"], stream_id: int):
+    def __init__(
+        self,
+        ffmpeg_normalize: FFmpegNormalize,
+        media_file: MediaFile,
+        stream_type: Literal["audio", "video", "subtitle"],
+        stream_id: int,
+    ):
         """
         Create a MediaStream object.
 
@@ -60,17 +70,17 @@ class MediaStream:
 
 
 class VideoStream(MediaStream):
-    def __init__(self, ffmpeg_normalize, media_file, stream_id):
-        super().__init__(
-            ffmpeg_normalize, media_file, "video", stream_id
-        )
+    def __init__(
+        self, ffmpeg_normalize: FFmpegNormalize, media_file: MediaFile, stream_id: int
+    ):
+        super().__init__(ffmpeg_normalize, media_file, "video", stream_id)
 
 
 class SubtitleStream(MediaStream):
-    def __init__(self, ffmpeg_normalize, media_file, stream_id):
-        super().__init__(
-            ffmpeg_normalize, media_file, "subtitle", stream_id
-        )
+    def __init__(
+        self, ffmpeg_normalize: FFmpegNormalize, media_file: MediaFile, stream_id: int
+    ):
+        super().__init__(ffmpeg_normalize, media_file, "subtitle", stream_id)
 
 
 class AudioStream(MediaStream):
@@ -79,9 +89,9 @@ class AudioStream(MediaStream):
         ffmpeg_normalize: FFmpegNormalize,
         media_file: MediaFile,
         stream_id: int,
-        sample_rate: Union[int, None],
-        bit_depth: Union[int, None],
-        duration: Union[float, None],
+        sample_rate: int | None,
+        bit_depth: int | None,
+        duration: float | None,
     ):
         """
         Create an AudioStream object.
@@ -94,9 +104,7 @@ class AudioStream(MediaStream):
             bit_depth (int): bit depth in bits
             duration (float): duration in seconds
         """
-        super().__init__(
-            ffmpeg_normalize, media_file, "audio", stream_id
-        )
+        super().__init__(ffmpeg_normalize, media_file, "audio", stream_id)
 
         self.loudness_statistics: LoudnessStatistics = {
             "ebu": None,
@@ -114,14 +122,16 @@ class AudioStream(MediaStream):
             and self.duration
             and self.duration <= 3
         ):
-            logger.warning(
+            _logger.warning(
                 "Audio stream has a duration of less than 3 seconds. "
                 "Normalization may not work. "
                 "See https://github.com/slhck/ffmpeg-normalize/issues/87 for more info."
             )
 
     @staticmethod
-    def _constrain(number: float, min_range: float, max_range: float, name: Union[str, None] = None) -> float:
+    def _constrain(
+        number: float, min_range: float, max_range: float, name: str | None = None
+    ) -> float:
         """
         Constrain a number between two values.
 
@@ -141,7 +151,7 @@ class AudioStream(MediaStream):
             raise ValueError("min must be smaller than max")
         result = max(min(number, max_range), min_range)
         if result != number and name is not None:
-            logger.warning(
+            _logger.warning(
                 f"Constraining {name} to range of [{min_range}, {max_range}]: {number} -> {result}"
             )
         return result
@@ -177,7 +187,7 @@ class AudioStream(MediaStream):
         elif self.bit_depth in [16, 24, 32, 64]:
             return f"pcm_s{self.bit_depth}le"
         else:
-            logger.warning(
+            _logger.warning(
                 f"Unsupported bit depth {self.bit_depth}, falling back to pcm_s16le"
             )
             return "pcm_s16le"
@@ -201,14 +211,14 @@ class AudioStream(MediaStream):
         filter_str = input_label + ",".join(filter_chain)
         return filter_str
 
-    def parse_astats(self) -> Generator[int, None, None]:
+    def parse_astats(self) -> Iterator[int]:
         """
         Use ffmpeg with astats filter to get the mean (RMS) and max (peak) volume of the input file.
 
         Yields:
             int: The progress of the command.
         """
-        logger.info(f"Running first pass astats filter for stream {self.stream_id}")
+        _logger.info(f"Running first pass astats filter for stream {self.stream_id}")
 
         filter_str = self._get_filter_str_with_pre_filter(
             "astats=measure_overall=Peak_level+RMS_level:measure_perchannel=0"
@@ -229,11 +239,11 @@ class AudioStream(MediaStream):
             NUL,
         ]
 
-        cmd_runner = CommandRunner(cmd)
-        yield from cmd_runner.run_ffmpeg_command()
+        cmd_runner = CommandRunner()
+        yield from cmd_runner.run_ffmpeg_command(cmd)
         output = cmd_runner.get_output()
 
-        logger.debug(
+        _logger.debug(
             f"astats command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}"
         )
 
@@ -259,14 +269,14 @@ class AudioStream(MediaStream):
                 f"Could not get max volume for {self.media_file.input_file}"
             )
 
-    def parse_loudnorm_stats(self) -> Generator[int, None, None]:
+    def parse_loudnorm_stats(self) -> Iterator[int]:
         """
         Run a first pass loudnorm filter to get measured data.
 
         Yields:
             int: The progress of the command.
         """
-        logger.info(f"Running first pass loudnorm filter for stream {self.stream_id}")
+        _logger.info(f"Running first pass loudnorm filter for stream {self.stream_id}")
 
         opts = {
             "i": self.media_file.ffmpeg_normalize.target_level,
@@ -298,11 +308,11 @@ class AudioStream(MediaStream):
             NUL,
         ]
 
-        cmd_runner = CommandRunner(cmd)
-        yield from cmd_runner.run_ffmpeg_command()
+        cmd_runner = CommandRunner()
+        yield from cmd_runner.run_ffmpeg_command(cmd)
         output = cmd_runner.get_output()
 
-        logger.debug(
+        _logger.debug(
             f"Loudnorm first pass command output: {CommandRunner.prune_ffmpeg_progress_from_output(output)}"
         )
 
@@ -313,12 +323,12 @@ class AudioStream(MediaStream):
         )
 
     @staticmethod
-    def _parse_loudnorm_output(output_lines: List[str]) -> EbuLoudnessStatistics:
+    def _parse_loudnorm_output(output_lines: list[str]) -> EbuLoudnessStatistics:
         """
         Parse the output of a loudnorm filter to get the EBU loudness statistics.
 
         Args:
-            output_lines (List[str]): The output lines of the loudnorm filter.
+            output_lines (list[str]): The output lines of the loudnorm filter.
 
         Raises:
             FFmpegNormalizeError: When the output could not be parsed.
@@ -326,8 +336,8 @@ class AudioStream(MediaStream):
         Returns:
             EbuLoudnessStatistics: The EBU loudness statistics.
         """
-        loudnorm_start = False
-        loudnorm_end = False
+        loudnorm_start = 0
+        loudnorm_end = 0
         for index, line in enumerate(output_lines):
             if line.startswith("[Parsed_loudnorm"):
                 loudnorm_start = index + 1
@@ -346,7 +356,7 @@ class AudioStream(MediaStream):
                 "\n".join(output_lines[loudnorm_start:loudnorm_end])
             )
 
-            logger.debug(f"Loudnorm stats parsed: {json.dumps(loudnorm_stats)}")
+            _logger.debug(f"Loudnorm stats parsed: {json.dumps(loudnorm_stats)}")
 
             for key in [
                 "input_i",
@@ -368,7 +378,7 @@ class AudioStream(MediaStream):
                     # convert to floats
                     loudnorm_stats[key] = float(loudnorm_stats[key])
 
-            return loudnorm_stats
+            return cast(EbuLoudnessStatistics, loudnorm_stats)
         except Exception as e:
             raise FFmpegNormalizeError(
                 f"Could not parse loudnorm stats; wrong JSON format in string: {e}"
@@ -385,7 +395,7 @@ class AudioStream(MediaStream):
             )
 
         if float(self.loudness_statistics["ebu"]["input_i"]) > 0:
-            logger.warning(
+            _logger.warning(
                 "Input file had measured input loudness greater than zero "
                 f"({self.loudness_statistics['ebu']['input_i']}), capping at 0"
             )
@@ -394,7 +404,9 @@ class AudioStream(MediaStream):
         will_use_dynamic_mode = self.media_file.ffmpeg_normalize.dynamic
 
         if self.media_file.ffmpeg_normalize.keep_loudness_range_target:
-            logger.debug("Keeping target loudness range in second pass loudnorm filter")
+            _logger.debug(
+                "Keeping target loudness range in second pass loudnorm filter"
+            )
             self.media_file.ffmpeg_normalize.loudness_range_target = (
                 self.loudness_statistics["ebu"]["input_lra"]
             )
@@ -404,7 +416,7 @@ class AudioStream(MediaStream):
             < self.loudness_statistics["ebu"]["input_lra"]
             and not will_use_dynamic_mode
         ):
-            logger.warning(
+            _logger.warning(
                 f"Input file had loudness range of {self.loudness_statistics['ebu']['input_lra']}. "
                 f"This is larger than the loudness range target ({self.media_file.ffmpeg_normalize.loudness_range_target}). "
                 "Normalization will revert to dynamic mode. Choose a higher target loudness range if you want linear normalization. "
@@ -413,7 +425,7 @@ class AudioStream(MediaStream):
             will_use_dynamic_mode = True
 
         if will_use_dynamic_mode and not self.ffmpeg_normalize.sample_rate:
-            logger.warning(
+            _logger.warning(
                 "In dynamic mode, the sample rate will automatically be set to 192 kHz by the loudnorm filter. "
                 "Specify -ar/--sample-rate to override it."
             )
@@ -424,11 +436,21 @@ class AudioStream(MediaStream):
             "i": self.media_file.ffmpeg_normalize.target_level,
             "lra": self.media_file.ffmpeg_normalize.loudness_range_target,
             "tp": self.media_file.ffmpeg_normalize.true_peak,
-            "offset": self._constrain(float(stats["target_offset"]), -99, 99, name="target_offset"),
-            "measured_i": self._constrain(float(stats["input_i"]), -99, 0, name="input_i"),
-            "measured_lra": self._constrain(float(stats["input_lra"]), 0, 99, name="input_lra"),
-            "measured_tp": self._constrain(float(stats["input_tp"]), -99, 99, name="input_tp"),
-            "measured_thresh": self._constrain(float(stats["input_thresh"]), -99, 0, name="input_thresh"),
+            "offset": self._constrain(
+                float(stats["target_offset"]), -99, 99, name="target_offset"
+            ),
+            "measured_i": self._constrain(
+                float(stats["input_i"]), -99, 0, name="input_i"
+            ),
+            "measured_lra": self._constrain(
+                float(stats["input_lra"]), 0, 99, name="input_lra"
+            ),
+            "measured_tp": self._constrain(
+                float(stats["input_tp"]), -99, 99, name="input_tp"
+            ),
+            "measured_thresh": self._constrain(
+                float(stats["input_thresh"]), -99, 0, name="input_thresh"
+            ),
             "linear": "false" if self.media_file.ffmpeg_normalize.dynamic else "true",
             "print_format": "json",
         }
@@ -446,7 +468,10 @@ class AudioStream(MediaStream):
         Returns:
             str: ffmpeg volume filter string
         """
-        if self.loudness_statistics["max"] is None or self.loudness_statistics["mean"] is None:
+        if (
+            self.loudness_statistics["max"] is None
+            or self.loudness_statistics["mean"] is None
+        ):
             raise FFmpegNormalizeError(
                 "First pass not run, no mean/max volume to normalize to"
             )
@@ -463,12 +488,12 @@ class AudioStream(MediaStream):
                 "Can only set adjustment for peak and RMS normalization"
             )
 
-        logger.info(
+        _logger.info(
             f"Adjusting stream {self.stream_id} by {adjustment} dB to reach {target_level}"
         )
 
         clip_amount = self.loudness_statistics["max"] + adjustment
         if clip_amount > 0:
-            logger.warning(f"Adjusting will lead to clipping of {clip_amount} dB")
+            _logger.warning(f"Adjusting will lead to clipping of {clip_amount} dB")
 
         return f"volume={adjustment}dB"
